"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeOfferAndMatchTrade = void 0;
const web3_js_1 = require("@solana/web3.js");
const anchor_1 = require("@project-serum/anchor");
const spl_token_1 = require("@solana/spl-token");
function makeOfferAndMatchTrade(program, params) {
    return __awaiter(this, void 0, void 0, function* () {
        const { configAccount, marketAccount, marketTokenVault, marketNativeVault, side, minTradeSize, offerAccount, kycCert, user, userTokenAccount, useBondless, remainingAccounts, offerQuantity, offerAmount, fiatAmount, tradeIds, bumps, bondType, } = params;
        const byteBumps = Buffer.from(bumps);
        const tradeIdsConverted = tradeIds.map((item) => new anchor_1.BN(item));
        const totalOfferAmountBN = new anchor_1.BN(offerAmount);
        const ix = yield program.methods
            .makeOfferAndMatchTrade(side, bondType, minTradeSize, totalOfferAmountBN, fiatAmount, offerAccount.bump, offerQuantity, tradeIdsConverted, byteBumps)
            .accounts({
            configAccount,
            marketAccount,
            marketTokenVault,
            marketNativeVault,
            offerAccount: offerAccount.key,
            kycCert,
            userTokenAccount,
            user,
            tokenProgram: spl_token_1.TOKEN_PROGRAM_ID,
            systemProgram: web3_js_1.SystemProgram.programId,
            rent: web3_js_1.SYSVAR_RENT_PUBKEY,
        })
            .remainingAccounts(remainingAccounts)
            .instruction();
        return {
            instructions: [ix],
            cleanupInstructions: [],
            signers: [],
        };
    });
}
exports.makeOfferAndMatchTrade = makeOfferAndMatchTrade;
